@@ -26,7 +26,7 @@ _install_fido2() {
 
 
 check() {
-	command -v zfs-tpm-list > /dev/null || return 1
+	require_binaries zfs-tpm-list || return
 
 	# shellcheck disable=SC2154
 	if [ -n "$hostonly" ]; then
